@@ -197,7 +197,9 @@ class SpotifyBrowse(SpotifyBase):
         """
         Get a list of recommended tracks for seeds.
 
-        Up to 5 seed values may be provided as artists, genres and tracks.
+        .. warning::
+            The total number of seeds provided in ``artist_ids``, ``genres``
+            and ``track_ids`` must be at least 1 and at most 5.
 
         Parameters
         ----------
@@ -206,7 +208,7 @@ class SpotifyBrowse(SpotifyBase):
         genres
             list of seed genre names
         track_ids
-            list of seed artist IDs
+            list of seed track IDs
         limit
             the number of items to return (1..100)
         market
