@@ -17,6 +17,7 @@ class IdentifierType(StrEnum):
     playlist = 'playlist'
     show = 'show'
     track = 'track'
+    user = 'user'
 
 
 def check_type(type_: Union[str, IdentifierType]) -> None:
@@ -38,7 +39,9 @@ all_base62 = re.compile('^[0-9a-zA-Z]*$')
 
 def check_id(id_: str) -> None:
     """
-    Validate resource ID.
+    Validate resource ID to be base 62.
+
+    Note that user IDs can have special characters, so they cannot be validated.
 
     Raises
     ------
@@ -71,7 +74,8 @@ def to_uri(type_: Union[str, IdentifierType], id_: str) -> str:
         On invalid type or ID.
     """
     check_type(type_)
-    check_id(id_)
+    if type_ != IdentifierType.user:
+        check_id(id_)
     return f'spotify:{type_}:{id_}'
 
 
@@ -97,7 +101,10 @@ def to_url(type_: Union[str, IdentifierType], id_: str) -> str:
         On invalid type or ID.
     """
     check_type(type_)
-    check_id(id_)
+    if type_ != IdentifierType.user:
+        check_id(id_)
+    else:
+        id_ = id_.replace('#', '%23')
     return f'https://open.spotify.com/{type_}/{id_}'
 
 
@@ -118,14 +125,19 @@ def from_uri(uri: str) -> Tuple[str, str]:
     Raises
     ------
     ConversionError
-        On invalid type or ID.
+        On invalid format, prefix, type or ID.
     """
-    spotify, type_, id_ = uri.split(':')
+    try:
+        spotify, type_, id_ = uri.split(':')
+        if spotify != 'spotify':
+            raise ValueError()
+    except ValueError as e:
+        msg = f'Invalid URI: expected format "spotify:{{type}}:{{id}}", got "{uri}"!'
+        raise ConversionError(msg) from e
 
-    if spotify != 'spotify':
-        raise ConversionError(f'Invalid URI prefix "{spotify}"!')
     check_type(type_)
-    check_id(id_)
+    if type_ != IdentifierType.user:
+        check_id(id_)
 
     return type_, id_
 
@@ -141,6 +153,8 @@ def from_url(url: str) -> Tuple[str, str]:
     """
     Parse type and ID from an URL.
 
+    Any parameters in the URL will be ignored.
+
     Parameters
     ----------
     url
@@ -154,14 +168,21 @@ def from_url(url: str) -> Tuple[str, str]:
     Raises
     ------
     ConversionError
-        On invalid type or ID.
+        On invalid format, prefix, type or ID.
     """
-    *prefixes, type_, id_ = url.split('/')
-    prefix = '/'.join(prefixes)
+    try:
+        *prefixes, type_, id_ = url.split('/')
+        prefix = '/'.join(prefixes)
+        if prefix not in _url_prefixes:
+            raise ValueError()
+    except ValueError as e:
+        valid_url = '[http[s]://]open.spotify.com/{type}/{id}'
+        msg = f'Invalid URL: expected format "{valid_url}", got "{url}"!'
+        raise ConversionError(msg) from e
 
-    if prefix not in _url_prefixes:
-        raise ConversionError(f'Invalid URL prefix "{prefix}"!')
+    id_ = id_.split('?')[0]
     check_type(type_)
-    check_id(id_)
+    if type_ != IdentifierType.user:
+        check_id(id_)
 
     return type_, id_
