@@ -3,11 +3,12 @@ import json
 from enum import Enum
 from typing import Union, TypeVar, List
 from pprint import pprint
+from warnings import warn
 from datetime import datetime
 from dataclasses import dataclass, asdict, fields
 
 
-class StrEnum(Enum):
+class StrEnum(str, Enum):
     """Convert enumeration members to strings using their name."""
 
     def __str__(self):
@@ -83,11 +84,16 @@ def field_repr(field, value) -> str:
     if isinstance(value, Model):
         text = member_repr(type(value))
     elif isinstance(value, list):
-        f_type = field.type.__args__[0]
-        if issubclass(f_type, Model):
-            f_str = member_repr(f_type)
+        outer_type = field.type
+        if outer_type.__origin__ is Union:
+            outer_type = outer_type.__args__[0]
+
+        inner_type = outer_type.__args__[0]
+
+        if issubclass(inner_type, Model):
+            f_str = member_repr(inner_type)
         else:
-            f_str = f_type.__name__
+            f_str = inner_type.__name__
 
         text = f'[{len(value)} x {f_str}]'
     elif isinstance(value, dict):
@@ -163,6 +169,10 @@ class Serialisable:
         pprint(self.asbuiltin(), depth=depth, compact=compact, **pprint_kwargs)
 
 
+class UnknownModelAttributeWarning(RuntimeWarning):
+    """The response model contains an unknown attribute."""
+
+
 @dataclass(repr=False)
 class Model(Serialisable):
     """Dataclass that provides a readable ``repr`` of its fields."""
@@ -179,6 +189,31 @@ class Model(Serialisable):
 
         return '\n'.join(lines)
 
+    @classmethod
+    def from_kwargs(cls, kwargs):
+        """Create the Model and patch unknown kwargs in."""
+        # Adapted from Stack Overflow: https://stackoverflow.com/a/55101438/7089239
+        cls_fields = {field.name for field in fields(cls)}
+
+        # split into known and unknown kwargs
+        known_kwargs, unknown_kwargs = {}, {}
+        for name, val in kwargs.items():
+            if name in cls_fields:
+                known_kwargs[name] = val
+            else:
+                unknown_kwargs[name] = val
+
+        model = cls(**known_kwargs)
+
+        for name, val in unknown_kwargs.items():
+            setattr(model, name, val)
+            msg = (
+                f'\nResponse contains unknown attribute: `{name}`\n'
+                'This warning may be safely ignored. Please consider upgrading Tekore.'
+            )
+            warn(msg, UnknownModelAttributeWarning, stacklevel=5)
+        return model
+
 
 T = TypeVar('T')
 
