@@ -11,7 +11,9 @@ class Request:
     url: str
     params: Optional[dict] = None
     headers: Optional[dict] = None
-    data: Union[str, dict, None] = None
+    data: Optional[dict] = None
+    json: Optional[dict] = None
+    content: Optional[str] = None
 
 
 @dataclass
@@ -53,3 +55,7 @@ class Sender(ABC):
     @abstractmethod
     def is_async(self) -> bool:
         """Sender asynchronicity mode."""
+
+    @abstractmethod
+    def close(self) -> Union[None, Coroutine[None, None, None]]:
+        """Close underlying client."""
