@@ -39,6 +39,8 @@ class SyncSender(Sender):
             params=request.params,
             headers=request.headers,
             data=request.data,
+            json=request.json,
+            content=request.content,
         )
         return Response(
             url=str(response.url),
@@ -52,6 +54,10 @@ class SyncSender(Sender):
         """Sender asynchronicity, always :class:`False`."""
         return False
 
+    def close(self) -> None:
+        """Close the underlying synchronous client."""
+        return self.client.close()
+
 
 class AsyncSender(Sender):
     """
@@ -80,6 +86,8 @@ class AsyncSender(Sender):
             params=request.params,
             headers=request.headers,
             data=request.data,
+            json=request.json,
+            content=request.content,
         )
         return Response(
             url=str(response.url),
@@ -92,3 +100,7 @@ class AsyncSender(Sender):
     def is_async(self) -> bool:
         """Sender asynchronicity, always :class:`True`."""
         return True
+
+    async def close(self) -> None:
+        """Close the underlying asynchronous client."""
+        return await self.client.aclose()
